## v0.5.0 (2025-02-05)

### ✨ Features

- implement auto-estimating initial coords for fit_with_corr method (#14)

[main a0d512f] bump: version 0.4.0 → 0.5.0
 2 files changed, 2 insertions(+), 2 deletions(-)

